import styles from './MemberItem.module.css';
import { Component } from "solid-js";
import { Group, User, api } from "../api";
import { showDialog, showMessageDialog } from "../state";
import { errorToString } from "../util";
import { BsTrash } from 'solid-icons/bs';

export interface MemberItemProps {
	group: Group,
	member: User,
	onDelete: (m: User) => void
}

const MemberItem: Component<MemberItemProps> = (props) => {

	const deleteMember = async () => {
		showDialog({
			title: 'Remove member',
			text: 'Do you want to remove this member?',
			buttons: [
				{
					name: 'Remove',
					type: 'danger',
					closeOnClick: true,
					action: async () => {
						try {
							await api().removeMember(props.group.id, props.member.username);
							props.onDelete(props.member);
						} catch (e) {
							showMessageDialog('Failed to remove member', errorToString(e));
						}
					}
				},
				{
					name: 'Cancel',
					closeOnClick: true,
					action: () => { }
				}
			]
		});
	};

	return (
		<div class={styles.member}>
			<div class={styles.memberDetails}>
				<div class={styles.memberName}>
					<span innerText={props.member.displayName} />
				</div>
				<div>
					<button onClick={deleteMember}><BsTrash /></button>
				</div>
			</div>
		</div >
	)
}

export default MemberItem;
